Discord Hero Developer Tools
================================

Discord Hero Developer Tools is a Debugging and Experimenting extension for Discord Hero. You can load, reload and unload extensions.

Legal stuff
-----------

Discord is a registered trademark of Discord Inc.

Except as otherwise noted, Discord Hero Developer Tools is
licensed under the Apache License, Version 2.0 (`<LICENSE.Apache-2.0>`__ or
`<http://www.apache.org/licenses/LICENSE-2.0>`__) or
the MIT license (`<LICENSE.MIT>`__ or
`<http://opensource.org/licenses/MIT>`__), at your option.

Unless you explicitly state otherwise, any contribution intentionally
submitted for inclusion in the work by you, as defined in the
Apache-2.0 license, shall be dual licensed under the Apache
License, Version 2.0, and the MIT license, without any
additional terms or conditions.

SPDX-License-Identifier: Apache-2.0
